# About Ganymede

Built as cloud native, Ganymede is a fully managed platform,
continuously updated with high-quality, curated, and cross validated
data. Ganymede is purpose built for the financial data markets ever
increasing data volumes, allowing clients to query against large data
sets, including tick-by-tick, sampled, daily, corporate actions, ESG and
reference data. Packed with a broad range of analytics, the solution is
optimized for fast response times, supports full order book natively and
allows fine grained/customizable trade and quote conditions mapping and
filtering.

For further information, please visit [Ganymede home page](https://ganymede.cloud)

## About this package


This package provides up-to-date gRPC clients to access [Ganymede API](https://ganymede.cloud/api-documentation.html)

Python version 3

## About us


[Systemathics](https://systemathics.com) is a French fintech founded
in 2008 developing its innovative products with the highest quality
standards 100% in France. Our main mission is to provide global
investors with a complete end-to-end solution to systematize alpha
generation in a robust way. From data pre and post trade analysis,
back-testing, risk assessment and signal generation to day-to-day
execution in production and everything in between.
